#ifndef NT2_INCLUDE_FUNCTIONS_DEINTERLEAVE_SECOND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_DEINTERLEAVE_SECOND_HPP_INCLUDED

#include <nt2/swar/include/functions/deinterleave_second.hpp>

#endif
